#' Switches valid POIs from minor to major path divergences
#' @param inSegs  (list) list of input COMIDs representing POIs
#' @param nhdDF (sf data.frame) (data frame) valid data frame of NHD flowlines
#'
#' @return (sf data.frame) Corresponding major path COMID for POI
#' @importFrom dplyr filter inner_join select left_join mutate
#' @importFrom sf st_drop_geometry
#' @export
switchDiv <- function(insegs, nhdDF){

  div_segs <- filter(nhdDF, COMID %in% insegs$COMID)
  if (2 %in% div_segs$Divergence){
    message("Switching divergence to other fork")

    # Look Upstream
    upstream <- st_drop_geometry(nhdDF) %>%
      inner_join(st_drop_geometry(div_segs) %>%
                   filter(Divergence == 2) %>%
                   select(COMID, Hydroseq),
                 by = c("DnMinorHyd" = "Hydroseq"))

    # From Upstream Segment switch POI to the downstream major/main path
    insegs_maj <- st_drop_geometry(nhdDF) %>%
      inner_join(upstream %>% select(COMID.y, DnHydroseq),
                 by = c("Hydroseq" = "DnHydroseq")) %>%
      select(COMID, COMID.y)

    insegs <- insegs %>%
      left_join(insegs_maj, by = c("COMID" = "COMID.y")) %>%
      mutate(COMID = ifelse(!is.na(COMID.y), COMID.y, COMID)) %>%
      select(-COMID.y)

  } else {
    message("no divergences present in POI set")
  }

  return(insegs)
}
